import fs from "node:fs/promises";
import path from "node:path";
import process from "node:process";
import yaml from "yaml";
import { z } from "zod";
const ExtensionConfigurationFileSchema = z.object({
    config: z
        .object({
        slug: z.string().min(1).optional(),
        ui: z
            .object({
            surfaces: z.array(z.string().min(1)).optional(),
        })
            .optional(),
    })
        .optional(),
});
const ExtensionConfiguration = z.object({
    slug: z.string().min(1),
    ui: z.object({
        surfaces: z.array(z.string().min(1)),
    }),
});
const possibleFiles = [
    "integration.yaml",
    "integration.yml",
    "netlify-integration.yaml",
    "netlify-integration.yml",
];
const getConfigurationFile = async (cwd) => {
    for (const filename of possibleFiles.map((filename) => path.resolve(cwd, filename))) {
        try {
            const filepath = path.resolve(cwd, filename);
            const result = await fs.stat(filepath);
            if (result.isFile()) {
                return filepath;
            }
        }
        catch {
            // Continue
        }
    }
    return null;
};
export const getExtensionConfiguration = async (cwd) => {
    const filepath = await getConfigurationFile(cwd);
    if (filepath === null) {
        throw new Error(`No extension configuration file found in ${cwd}`);
    }
    try {
        const result = await fs.readFile(filepath, "utf8");
        const { config = {} } = ExtensionConfigurationFileSchema.parse(yaml.parse(result));
        const buildSiteId = (process.env["SITE_ID"] ?? "").trim();
        if (buildSiteId !== "") {
            const metadataRes = await fetch(`https://api.netlifysdk.com/meta/integration-host-site/${buildSiteId}`);
            if (metadataRes.status === 200) {
                const { slug } = (await metadataRes.json());
                config.slug = slug;
            }
        }
        return ExtensionConfiguration.parse({
            ...config,
            ui: {
                ...config.ui,
                surfaces: config.ui?.surfaces ?? [],
            },
        });
    }
    catch {
        throw new Error(`Configuration file at ${filepath} is invalid`);
    }
};
//# sourceMappingURL=utils.js.map